import { Message } from 'element-ui'
import axios from 'axios'
import Adapter from 'axios-mock-adapter'
import { get, isEmpty, merge } from 'lodash'
import qs from 'qs'
import util from '@/libs/util'
import store from '@/store'
import { parse } from './tools'

/**
 * @description 记录和显示错误
 * @param {Error} error 错误对象
 */
/* function handleError (error) {
  // 添加到日志
  store.dispatch('d2admin/log/push', {
    message: '数据请求异常',
    type: 'danger',
    meta: {
      error
    }
  })
  // 打印到控制台
  if (process.env.NODE_ENV === 'development') {
    util.log.danger('>>>>>> Error >>>>>>')
    console.log(error)
  }
  // 显示提示
  Message({
    message: error.message,
    type: 'error',
    duration: 5 * 1000
  })
} */

/**
 * @description 创建请求实例
 */
function createService () {
  // 创建一个 axios 实例
  const service = axios.create()
  // 请求拦截
  service.interceptors.request.use(
    config => config,
    error => {
      // 发送失败
    
      return Promise.reject(error)
    }
  )
  // 响应拦截
 /*  service.interceptors.response.use(
    response => {
      // const res = response.data //
      // return res
      // dataAxios 是 axios 返回数据中的 data
      // const res = response.data 
      // return res
      const dataAxios = response.data
      // 这个状态码是和后端约定的
      const { code } = dataAxios
      console.log(dataAxios,"dataAxios")
      console.log(code,"///")
      // 根据 code 进行判断
      if (code === undefined) {
        // 如果没有 code 代表这不是项目后端开发的接口 比如可能是 D2Admin 请求最新版本
        return dataAxios
      } else {
        // 有 code 代表这是一个后端接口 可以进行进一步的判断
        switch (code) {
          case 200:
            // [ 示例 ] code === 0 代表没有错误
            return dataAxios.data
           
          case 'xxx':
            // [ 示例 ] 其它和后台约定的 code
            errorCreate(`[ code: xxx ] ${dataAxios.msg}: ${response.config.url}`)
            break
          default:
            // 不是正确的 code
            errorCreate(`${dataAxios.msg}: ${response.config.url}`)
            break
        }
      }
    },
    error => {
      const status = get(error, 'response.status')
      switch (status) {
        case 400: error.message = '请求错误'; break
        case 401: error.message = '未授权，请登录'; break
        case 403: error.message = '拒绝访问'; break
        case 404: error.message = `请求地址出错: ${error.response.config.url}`; break
        case 408: error.message = '请求超时'; break
        case 500: error.message = '服务器内部错误'; break
        case 501: error.message = '服务未实现'; break
        case 502: error.message = '网关错误'; break
        case 503: error.message = '服务不可用'; break
        case 504: error.message = '网关超时'; break
        case 505: error.message = 'HTTP版本不受支持'; break
        default: break
      }
      handleError(error)
      throw error
    }
  )*/


 // 添加响应拦截器
 
service.interceptors.response.use(
  response => {
    // 对响应数据做点什么
    const res = response.data
    if(res.code ==undefined) {
      return res.data
    }
    // 有 code 判断为项目接口请求
    switch (res.code) {
      // 返回响应内容
      case 0: return res.data
      // 例如在 code 401 情况下退回到登录页面
      case 401: throw new Error('请重新登录')
      // 根据需要添加其它判断
      // case 403: MessageBox.alert('身份失效，请重新登录', '确认退出', {
      //   confirmButtonText: '确定',
      //   callback:()=>{

      //     this.$router.push({
      //       path:"/login"
      //     })
         
       
      //   }

      // })
      // default: throw new Error(`${response.data.msg}: ${response.config.url}`)
    }
    return res;
  }, function (error) {
 
    // 对响应错误做点什么
    return Promise.reject(error);
  });
  return service
} 

function stringify (data) {
  return qs.stringify(data, { allowDots: true, encode: false })
}

/**
 * @description 创建请求方法
 * @param {Object} service axios 实例
 */
function createRequest (service) {
  return function (config) {
    const token = util.cookies.get('token')
    console.log(token,"se...")
    const configDefault = {
      headers: {
        // Authorization: token,
        token: token,
        'Content-Type': get(config, 'headers.Content-Type', 'application/json')
      },
      timeout: 5000,
      baseURL: process.env.VUE_APP_API,
      data: {}
    }
    const option = merge(configDefault, config)
    // 处理 get 请求的参数
    // 请根据实际需要修改
    if (!isEmpty(option.params)) {
      option.url = option.url + '?' + stringify(option.params)
      option.params = {}
    }
    // 当需要以 form 形式发送时 处理发送的数据
    // 请根据实际需要修改
   
    if (!isEmpty(option.data) && option.headers['Content-Type'] === 'application/x-www-form-urlencoded') {
    
      option.data = stringify(option.data)
      // option.data = parse(option.data)
     
    }
    return service(option)
  }
}

// 用于真实网络请求的实例和请求方法
export const service = createService()
export const request = createRequest(service)

// 用于模拟网络请求的实例和请求方法
export const serviceForMock = createService()
export const requestForMock = createRequest(serviceForMock)

// 网络请求数据模拟工具
export const mock = new Adapter(serviceForMock)
